# Exceptions

These are all the custom exceptions you might encounter when using `iCal-library`.

::: ical_library.CalendarParentRelationError

::: ical_library.VEventExpansionFailed

::: ical_library.MissingRequiredProperty